@@ -1,4 +1,7 @@
 import math
+import numpy as np
+import matplotlib.pyplot as plt
+import scipy
 
 def TR(n):
 	tr=n*(n-1)
@@ -22,8 +25,10 @@ def pow(x, y):
 	n=x**y
 	return n
 
-def pythagorean(a, b):
-	a**2+b**2=c2
-	c=sqrt(c2)
-	return c
+def absgraph(x):
+        pass
+
+def dectofrac(dec):
+    frac=str(dec)+'/1'
+    return frac
 
